Class: Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb

Overview

Client for the CloudLocationFinder service.

Service describing handlers for resources

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#cloud_location_path, #location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new CloudLocationFinder client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the CloudLocationFinder client.

Yield Parameters:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 140

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/locationfinder/v1/service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @cloud_location_finder_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::LocationFinder::V1::CloudLocationFinder::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @cloud_location_finder_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @cloud_location_finder_stub.endpoint
    config.universe_domain = @cloud_location_finder_stub.universe_domain
    config.logger = @cloud_location_finder_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


204
205
206
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 204

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the CloudLocationFinder Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all CloudLocationFinder clients
::Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "LocationFinder", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_cloud_locations.timeout = 60.0
    default_config.rpcs.list_cloud_locations.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_cloud_location.timeout = 60.0
    default_config.rpcs.get_cloud_location.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.search_cloud_locations.timeout = 60.0
    default_config.rpcs.search_cloud_locations.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the CloudLocationFinder Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



110
111
112
113
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 110

def configure
  yield @config if block_given?
  @config
end

#get_cloud_location(request, options = nil) ⇒ ::Google::Cloud::LocationFinder::V1::CloudLocation #get_cloud_location(name: nil) ⇒ ::Google::Cloud::LocationFinder::V1::CloudLocation

Retrieves a resource containing information about a cloud location.

Examples:

Basic example

require "google/cloud/location_finder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::LocationFinder::V1::GetCloudLocationRequest.new

# Call the get_cloud_location method.
result = client.get_cloud_location request

# The returned object is of type Google::Cloud::LocationFinder::V1::CloudLocation.
p result

Overloads:

  • #get_cloud_location(request, options = nil) ⇒ ::Google::Cloud::LocationFinder::V1::CloudLocation

    Pass arguments to get_cloud_location via a request object, either of type GetCloudLocationRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::LocationFinder::V1::GetCloudLocationRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_cloud_location(name: nil) ⇒ ::Google::Cloud::LocationFinder::V1::CloudLocation

    Pass arguments to get_cloud_location via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Name of the resource.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Google::Cloud::LocationFinder::V1::CloudLocation)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Google::Cloud::LocationFinder::V1::CloudLocation)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 371

def get_cloud_location request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::LocationFinder::V1::GetCloudLocationRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_cloud_location..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::LocationFinder::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_cloud_location.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_cloud_location.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_location_finder_stub.call_rpc :get_cloud_location, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_cloud_locations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation> #list_cloud_locations(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>

Lists cloud locations under a given project and location.

Examples:

Basic example

require "google/cloud/location_finder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::LocationFinder::V1::ListCloudLocationsRequest.new

# Call the list_cloud_locations method.
result = client.list_cloud_locations request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::LocationFinder::V1::CloudLocation.
  p item
end

Overloads:

  • #list_cloud_locations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>

    Pass arguments to list_cloud_locations via a request object, either of type ListCloudLocationsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::LocationFinder::V1::ListCloudLocationsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_cloud_locations(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>

    Pass arguments to list_cloud_locations via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of cloud locations. Format: projects/{project}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of cloud locations to return per page. The service might return fewer cloud locations than this value. If unspecified, server will pick an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token identifying a page of results the server should return. Provide page token returned by a previous 'ListCloudLocations' call to retrieve the next page of results. When paginating, all other parameters provided to 'ListCloudLocations' must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      Optional. A filter expression that filters resources listed in the response. The expression is in the form of field=value. For example, 'cloud_location_type=CLOUD_LOCATION_TYPE_REGION'. Multiple filter queries are space-separated. For example, 'cloud_location_type=CLOUD_LOCATION_TYPE_REGION territory_code="US"' By default, each expression is an AND expression. However, you can include AND and OR expressions explicitly.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 284

def list_cloud_locations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::LocationFinder::V1::ListCloudLocationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_cloud_locations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::LocationFinder::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_cloud_locations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_cloud_locations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_location_finder_stub.call_rpc :list_cloud_locations, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_location_finder_stub, :list_cloud_locations, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


211
212
213
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 211

def logger
  @cloud_location_finder_stub.logger
end

#search_cloud_locations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation> #search_cloud_locations(parent: nil, source_cloud_location: nil, page_size: nil, page_token: nil, query: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>

Searches for cloud locations from a given source location.

Examples:

Basic example

require "google/cloud/location_finder/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::LocationFinder::V1::CloudLocationFinder::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::LocationFinder::V1::SearchCloudLocationsRequest.new

# Call the search_cloud_locations method.
result = client.search_cloud_locations request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::LocationFinder::V1::CloudLocation.
  p item
end

Overloads:

  • #search_cloud_locations(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>

    Pass arguments to search_cloud_locations via a request object, either of type SearchCloudLocationsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::LocationFinder::V1::SearchCloudLocationsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #search_cloud_locations(parent: nil, source_cloud_location: nil, page_size: nil, page_token: nil, query: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>

    Pass arguments to search_cloud_locations via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of cloud locations. Format: projects/{project}/locations/{location}

    • source_cloud_location (::String) (defaults to: nil)

      Required. The source cloud location to search from. Example search can be searching nearby cloud locations from the source cloud location by latency.

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of cloud locations to return. The service might return fewer cloud locations than this value. If unspecified, server will pick an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token identifying a page of results the server should return. Provide Page token returned by a previous 'ListCloudLocations' call to retrieve the next page of results. When paginating, all other parameters provided to 'ListCloudLocations' must match the call that provided the page token.

    • query (::String) (defaults to: nil)

      Optional. The query string in search query syntax. While filter is used to filter the search results by attributes, query is used to specify the search requirements.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

  • response (::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>)
  • operation (::GRPC::ActiveCall::Operation)

Returns:

  • (::Gapic::PagedEnumerable<::Google::Cloud::LocationFinder::V1::CloudLocation>)

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 479

def search_cloud_locations request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::LocationFinder::V1::SearchCloudLocationsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.search_cloud_locations..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::LocationFinder::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.search_cloud_locations.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.search_cloud_locations.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_location_finder_stub.call_rpc :search_cloud_locations, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_location_finder_stub, :search_cloud_locations, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


120
121
122
# File 'lib/google/cloud/location_finder/v1/cloud_location_finder/client.rb', line 120

def universe_domain
  @cloud_location_finder_stub.universe_domain
end